@@ -1,11 +1,9 @@
 from .models import *
 from .sdk.dg_sdk import DexGuru
 
-__version__ = '0.1.1'
 
 __all__ = [
     'models',
-    'DexGuru',
     'AmmModel',
     'AmmListModel',
     'ChainModel',
